@@ -23,7 +23,7 @@
 
 #include "htmlfontspecification.h"
 
-static int html_font_size[7];
+static gfloat html_font_size[7];
 
 typedef struct _HtmlFontSpecificationPrivate HtmlFontSpecificationPrivate;
 
@@ -37,7 +37,7 @@ static gboolean html_font_spec_is_initialized = FALSE;
 static void
 html_font_specification_init_sizes ()
 {
-	gint base_size = 14;
+	gfloat base_size = 14.0;
 	PangoFontDescription *font_desc;
 	GtkSettings *settings;
 	gchar *font_name;
@@ -70,7 +70,7 @@ html_font_specification_new (gchar *family,
 			     HtmlFontWeightType weight,
 			     HtmlFontStretchType stretch, 
 			     HtmlFontDecorationType decoration,
-			     gint size)
+			     gfloat size)
 {
 	HtmlFontSpecificationPrivate *spec;
 
@@ -259,7 +259,7 @@ html_font_specification_get_html_size (HtmlFontSpecification *spec)
 	return best + 1;
 }
 
-gint
+gfloat
 html_font_description_html_size_to_pt (gint font_size) 
 {
 	if (font_size < 1)
