@@ -85,10 +85,6 @@ HTML_ACCESSIBLE_FACTORY (HTML_TYPE_BOX_TABLE_ACCESSIBLE, html_box_table_accessib
 HTML_ACCESSIBLE_FACTORY (HTML_TYPE_BOX_TEXT_ACCESSIBLE, html_box_text_accessible)
 #endif
 
-typedef enum {
-	HTML_VIEW_SCROLL_TO_TOP,
-	HTML_VIEW_SCROLL_TO_BOTTOM,
-} HtmlViewScrollToType;
 
 static gboolean
 set_adjustment_clamped (GtkAdjustment *adj, gdouble val)
@@ -111,7 +107,7 @@ set_adjustment_clamped (GtkAdjustment *adj, gdouble val)
     return FALSE;
 }
 
-static void
+void
 html_view_scroll_to_node (HtmlView *view, DomNode *node, HtmlViewScrollToType type)
 {
 	HtmlBox *box;
@@ -647,6 +643,14 @@ html_view_realize (GtkWidget *widget)
 	HtmlView *view;
 
 	view = HTML_VIEW (widget);
+
+	/*
+	 * GtkLayout uses the bg color for background but we want
+	 * to use base color.
+	 */	
+	widget->style = gtk_style_copy (widget->style);
+	widget->style->bg[GTK_STATE_NORMAL] = 
+		widget->style->base[GTK_STATE_NORMAL];
 	
 	if (GTK_WIDGET_CLASS (parent_class)->realize)
 		(* GTK_WIDGET_CLASS (parent_class)->realize) (widget);
